You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2020/11/15 15:40:40 UTC

[commons-lang] 03/03: Consistently use just the parameter name for the message of NullPointerExceptions.

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-lang.git

commit 43b2326713ab952833c2ed4c88fbb0b34cb65436
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Sun Nov 15 10:40:31 2020 -0500

    Consistently use just the parameter name for the message of
    NullPointerExceptions.
---
 .../java/org/apache/commons/lang3/CharRange.java   |  2 +-
 .../java/org/apache/commons/lang3/CharUtils.java   |  4 +-
 .../org/apache/commons/lang3/ClassPathUtils.java   | 16 ++---
 .../java/org/apache/commons/lang3/ClassUtils.java  |  2 +-
 .../java/org/apache/commons/lang3/ObjectUtils.java | 10 ++--
 src/main/java/org/apache/commons/lang3/Range.java  |  2 +-
 .../apache/commons/lang3/SerializationUtils.java   |  2 +-
 .../java/org/apache/commons/lang3/ThreadUtils.java | 14 ++---
 .../apache/commons/lang3/builder/DiffBuilder.java  |  8 +--
 .../apache/commons/lang3/builder/DiffResult.java   | 24 ++++----
 .../commons/lang3/builder/HashCodeBuilder.java     |  2 +-
 .../lang3/builder/ReflectionToStringBuilder.java   |  2 +-
 .../commons/lang3/builder/ToStringBuilder.java     |  2 +-
 .../lang3/concurrent/BasicThreadFactory.java       |  6 +-
 .../concurrent/CallableBackgroundInitializer.java  |  6 +-
 .../concurrent/MultiBackgroundInitializer.java     | 13 ++--
 .../commons/lang3/event/EventListenerSupport.java  |  8 +--
 .../org/apache/commons/lang3/math/Fraction.java    |  8 +--
 .../apache/commons/lang3/math/IEEE754rUtils.java   |  8 +--
 .../org/apache/commons/lang3/math/NumberUtils.java |  2 +-
 .../commons/lang3/reflect/ConstructorUtils.java    |  6 +-
 .../apache/commons/lang3/reflect/FieldUtils.java   | 26 ++++----
 .../apache/commons/lang3/reflect/MethodUtils.java  | 12 ++--
 .../apache/commons/lang3/reflect/TypeUtils.java    | 70 +++++++++++-----------
 .../org/apache/commons/lang3/time/DateUtils.java   |  2 +-
 .../org/apache/commons/lang3/time/FormatCache.java |  2 +-
 .../org/apache/commons/lang3/CharRangeTest.java    |  2 +-
 27 files changed, 130 insertions(+), 131 deletions(-)

diff --git a/src/main/java/org/apache/commons/lang3/CharRange.java b/src/main/java/org/apache/commons/lang3/CharRange.java
index 90977fb..62ee82b 100644
--- a/src/main/java/org/apache/commons/lang3/CharRange.java
+++ b/src/main/java/org/apache/commons/lang3/CharRange.java
@@ -187,7 +187,7 @@ final class CharRange implements Iterable<Character>, Serializable {
      * @throws IllegalArgumentException if {@code null} input
      */
     public boolean contains(final CharRange range) {
-        Validate.notNull(range, "The Range must not be null");
+        Validate.notNull(range, "range");
         if (negated) {
             if (range.negated) {
                 return start >= range.start && end <= range.end;
diff --git a/src/main/java/org/apache/commons/lang3/CharUtils.java b/src/main/java/org/apache/commons/lang3/CharUtils.java
index 4e07693..1119197 100644
--- a/src/main/java/org/apache/commons/lang3/CharUtils.java
+++ b/src/main/java/org/apache/commons/lang3/CharUtils.java
@@ -134,7 +134,7 @@ public class CharUtils {
      * @throws NullPointerException if the Character is null
      */
     public static char toChar(final Character ch) {
-        Validate.notNull(ch, "The Character must not be null");
+        Validate.notNull(ch, "ch");
         return ch.charValue();
     }
 
@@ -265,7 +265,7 @@ public class CharUtils {
      * @throws IllegalArgumentException if the Character is not ASCII numeric
      */
     public static int toIntValue(final Character ch) {
-        Validate.notNull(ch, "The character must not be null");
+        Validate.notNull(ch, "ch");
         return toIntValue(ch.charValue());
     }
 
diff --git a/src/main/java/org/apache/commons/lang3/ClassPathUtils.java b/src/main/java/org/apache/commons/lang3/ClassPathUtils.java
index df3773a..6b3a142 100644
--- a/src/main/java/org/apache/commons/lang3/ClassPathUtils.java
+++ b/src/main/java/org/apache/commons/lang3/ClassPathUtils.java
@@ -55,8 +55,8 @@ public class ClassPathUtils {
      * @throws java.lang.NullPointerException if either {@code context} or {@code resourceName} is null.
      */
     public static String toFullyQualifiedName(final Class<?> context, final String resourceName) {
-        Validate.notNull(context, "Parameter '%s' must not be null!", "context" );
-        Validate.notNull(resourceName, "Parameter '%s' must not be null!", "resourceName");
+        Validate.notNull(context, "context" );
+        Validate.notNull(resourceName, "resourceName");
         return toFullyQualifiedName(context.getPackage(), resourceName);
     }
 
@@ -77,8 +77,8 @@ public class ClassPathUtils {
      * @throws java.lang.NullPointerException if either {@code context} or {@code resourceName} is null.
      */
     public static String toFullyQualifiedName(final Package context, final String resourceName) {
-        Validate.notNull(context, "Parameter '%s' must not be null!", "context" );
-        Validate.notNull(resourceName, "Parameter '%s' must not be null!", "resourceName");
+        Validate.notNull(context, "context" );
+        Validate.notNull(resourceName, "resourceName");
         return context.getName() + "." + resourceName;
     }
 
@@ -99,8 +99,8 @@ public class ClassPathUtils {
      * @throws java.lang.NullPointerException if either {@code context} or {@code resourceName} is null.
      */
     public static String toFullyQualifiedPath(final Class<?> context, final String resourceName) {
-        Validate.notNull(context, "Parameter '%s' must not be null!", "context" );
-        Validate.notNull(resourceName, "Parameter '%s' must not be null!", "resourceName");
+        Validate.notNull(context, "context" );
+        Validate.notNull(resourceName, "resourceName");
         return toFullyQualifiedPath(context.getPackage(), resourceName);
     }
 
@@ -122,8 +122,8 @@ public class ClassPathUtils {
      * @throws java.lang.NullPointerException if either {@code context} or {@code resourceName} is null.
      */
     public static String toFullyQualifiedPath(final Package context, final String resourceName) {
-        Validate.notNull(context, "Parameter '%s' must not be null!", "context" );
-        Validate.notNull(resourceName, "Parameter '%s' must not be null!", "resourceName");
+        Validate.notNull(context, "context" );
+        Validate.notNull(resourceName, "resourceName");
         return context.getName().replace('.', '/') + "/" + resourceName;
     }
 
diff --git a/src/main/java/org/apache/commons/lang3/ClassUtils.java b/src/main/java/org/apache/commons/lang3/ClassUtils.java
index a6d1d1d..9cd9ede 100644
--- a/src/main/java/org/apache/commons/lang3/ClassUtils.java
+++ b/src/main/java/org/apache/commons/lang3/ClassUtils.java
@@ -1199,7 +1199,7 @@ public class ClassUtils {
      */
     private static String toCanonicalName(String className) {
         className = StringUtils.deleteWhitespace(className);
-        Validate.notNull(className, "className must not be null.");
+        Validate.notNull(className, "className");
         if (className.endsWith("[]")) {
             final StringBuilder classNameBuffer = new StringBuilder();
             while (className.endsWith("[]")) {
diff --git a/src/main/java/org/apache/commons/lang3/ObjectUtils.java b/src/main/java/org/apache/commons/lang3/ObjectUtils.java
index d68021f..b454e99 100644
--- a/src/main/java/org/apache/commons/lang3/ObjectUtils.java
+++ b/src/main/java/org/apache/commons/lang3/ObjectUtils.java
@@ -808,7 +808,7 @@ public class ObjectUtils {
      * @since 3.2
      */
     public static void identityToString(final Appendable appendable, final Object object) throws IOException {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         appendable.append(object.getClass().getName())
               .append(AT_SIGN)
               .append(Integer.toHexString(System.identityHashCode(object)));
@@ -866,7 +866,7 @@ public class ObjectUtils {
      */
     @Deprecated
     public static void identityToString(final StrBuilder builder, final Object object) {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         final String name = object.getClass().getName();
         final String hexString = Integer.toHexString(System.identityHashCode(object));
         builder.ensureCapacity(builder.length() +  name.length() + 1 + hexString.length());
@@ -891,7 +891,7 @@ public class ObjectUtils {
      * @since 2.4
      */
     public static void identityToString(final StringBuffer buffer, final Object object) {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         final String name = object.getClass().getName();
         final String hexString = Integer.toHexString(System.identityHashCode(object));
         buffer.ensureCapacity(buffer.length() + name.length() + 1 + hexString.length());
@@ -916,7 +916,7 @@ public class ObjectUtils {
      * @since 3.2
      */
     public static void identityToString(final StringBuilder builder, final Object object) {
-        Validate.notNull(object, "Cannot get the toString of a null object");
+        Validate.notNull(object, "object");
         final String name = object.getClass().getName();
         final String hexString = Integer.toHexString(System.identityHashCode(object));
         builder.ensureCapacity(builder.length() +  name.length() + 1 + hexString.length());
@@ -1063,7 +1063,7 @@ public class ObjectUtils {
     public static <T> T median(final Comparator<T> comparator, final T... items) {
         Validate.notEmpty(items, "null/empty items");
         Validate.noNullElements(items);
-        Validate.notNull(comparator, "null comparator");
+        Validate.notNull(comparator, "comparator");
         final TreeSet<T> sort = new TreeSet<>(comparator);
         Collections.addAll(sort, items);
         @SuppressWarnings("unchecked") //we know all items added were T instances
diff --git a/src/main/java/org/apache/commons/lang3/Range.java b/src/main/java/org/apache/commons/lang3/Range.java
index 2c9e4b7..5f8889f 100644
--- a/src/main/java/org/apache/commons/lang3/Range.java
+++ b/src/main/java/org/apache/commons/lang3/Range.java
@@ -223,7 +223,7 @@ public final class Range<T> implements Serializable {
      */
     public int elementCompareTo(final T element) {
         // Comparable API says throw NPE on null
-        Validate.notNull(element, "Element is null");
+        Validate.notNull(element, "element");
         if (isAfter(element)) {
             return -1;
         } else if (isBefore(element)) {
diff --git a/src/main/java/org/apache/commons/lang3/SerializationUtils.java b/src/main/java/org/apache/commons/lang3/SerializationUtils.java
index a8269ab..455845a 100644
--- a/src/main/java/org/apache/commons/lang3/SerializationUtils.java
+++ b/src/main/java/org/apache/commons/lang3/SerializationUtils.java
@@ -175,7 +175,7 @@ public class SerializationUtils {
      * @throws SerializationException (runtime) if the serialization fails
      */
     public static <T> T deserialize(final byte[] objectData) {
-        Validate.notNull(objectData, "The byte[] must not be null");
+        Validate.notNull(objectData, "objectData");
         return deserialize(new ByteArrayInputStream(objectData));
     }
 
diff --git a/src/main/java/org/apache/commons/lang3/ThreadUtils.java b/src/main/java/org/apache/commons/lang3/ThreadUtils.java
index fef3dc8..7d52695 100644
--- a/src/main/java/org/apache/commons/lang3/ThreadUtils.java
+++ b/src/main/java/org/apache/commons/lang3/ThreadUtils.java
@@ -50,7 +50,7 @@ public class ThreadUtils {
      *          thread groups from this thread's thread group up to the system thread group
      */
     public static Thread findThreadById(final long threadId, final ThreadGroup threadGroup) {
-        Validate.notNull(threadGroup, "The thread group must not be null");
+        Validate.notNull(threadGroup, "threadGroup");
         final Thread thread = findThreadById(threadId);
         if (thread != null && threadGroup.equals(thread.getThreadGroup())) {
             return thread;
@@ -73,7 +73,7 @@ public class ThreadUtils {
      *          thread groups from this thread's thread group up to the system thread group
      */
     public static Thread findThreadById(final long threadId, final String threadGroupName) {
-        Validate.notNull(threadGroupName, "The thread group name must not be null");
+        Validate.notNull(threadGroupName, "threadGroupName");
         final Thread thread = findThreadById(threadId);
         if (thread != null && thread.getThreadGroup() != null && thread.getThreadGroup().getName().equals(threadGroupName)) {
             return thread;
@@ -114,8 +114,8 @@ public class ThreadUtils {
      *          thread groups from this thread's thread group up to the system thread group
      */
     public static Collection<Thread> findThreadsByName(final String threadName, final String threadGroupName) {
-        Validate.notNull(threadName, "The thread name must not be null");
-        Validate.notNull(threadGroupName, "The thread group name must not be null");
+        Validate.notNull(threadName, "threadName");
+        Validate.notNull(threadGroupName, "threadGroupName");
 
         final Collection<ThreadGroup> threadGroups = findThreadGroups(new NamePredicate(threadGroupName));
 
@@ -305,7 +305,7 @@ public class ThreadUtils {
          */
         public NamePredicate(final String name) {
             super();
-            Validate.notNull(name, "The name must not be null");
+            Validate.notNull(name, "name");
             this.name = name;
         }
 
@@ -422,8 +422,8 @@ public class ThreadUtils {
      *          thread groups from this thread's thread group up to the system thread group
      */
     public static Collection<ThreadGroup> findThreadGroups(final ThreadGroup group, final boolean recurse, final ThreadGroupPredicate predicate) {
-        Validate.notNull(group, "The group must not be null");
-        Validate.notNull(predicate, "The predicate must not be null");
+        Validate.notNull(group, "group");
+        Validate.notNull(predicate, "predicate");
 
         int count = group.activeGroupCount();
         ThreadGroup[] threadGroups;
diff --git a/src/main/java/org/apache/commons/lang3/builder/DiffBuilder.java b/src/main/java/org/apache/commons/lang3/builder/DiffBuilder.java
index fed655d..f7d5fc8 100644
--- a/src/main/java/org/apache/commons/lang3/builder/DiffBuilder.java
+++ b/src/main/java/org/apache/commons/lang3/builder/DiffBuilder.java
@@ -104,8 +104,8 @@ public class DiffBuilder<T> implements Builder<DiffResult<T>> {
     public DiffBuilder(final T lhs, final T rhs,
             final ToStringStyle style, final boolean testTriviallyEqual) {
 
-        Validate.notNull(lhs, "lhs cannot be null");
-        Validate.notNull(rhs, "rhs cannot be null");
+        Validate.notNull(lhs, "lhs");
+        Validate.notNull(rhs, "rhs");
 
         this.diffs = new ArrayList<>();
         this.left = lhs;
@@ -949,7 +949,7 @@ public class DiffBuilder<T> implements Builder<DiffResult<T>> {
     public DiffBuilder<T> append(final String fieldName,
             final DiffResult<T> diffResult) {
         validateFieldNameNotNull(fieldName);
-        Validate.notNull(diffResult, "Diff result cannot be null");
+        Validate.notNull(diffResult, "diffResult");
         if (objectsTriviallyEqual) {
             return this;
         }
@@ -977,7 +977,7 @@ public class DiffBuilder<T> implements Builder<DiffResult<T>> {
     }
 
     private void validateFieldNameNotNull(final String fieldName) {
-        Validate.notNull(fieldName, "Field name cannot be null");
+        Validate.notNull(fieldName, "fieldName");
     }
 
 }
diff --git a/src/main/java/org/apache/commons/lang3/builder/DiffResult.java b/src/main/java/org/apache/commons/lang3/builder/DiffResult.java
index c55aafc..0a2361d 100644
--- a/src/main/java/org/apache/commons/lang3/builder/DiffResult.java
+++ b/src/main/java/org/apache/commons/lang3/builder/DiffResult.java
@@ -48,7 +48,7 @@ public class DiffResult<T> implements Iterable<Diff<?>> {
 
     private static final String DIFFERS_STRING = "differs from";
 
-    private final List<Diff<?>> diffs;
+    private final List<Diff<?>> diffList;
     private final T lhs;
     private final T rhs;
     private final ToStringStyle style;
@@ -63,7 +63,7 @@ public class DiffResult<T> implements Iterable<Diff<?>> {
      *            the left hand object
      * @param rhs
      *            the right hand object
-     * @param diffs
+     * @param diffList
      *            the list of differences, may be empty
      * @param style
      *            the style to use for the {@link #toString()} method. May be
@@ -71,13 +71,13 @@ public class DiffResult<T> implements Iterable<Diff<?>> {
      *            {@link ToStringStyle#DEFAULT_STYLE} is used
      * @throws NullPointerException if {@code lhs}, {@code rhs} or {@code diffs} is {@code null}
      */
-    DiffResult(final T lhs, final T rhs, final List<Diff<?>> diffs,
+    DiffResult(final T lhs, final T rhs, final List<Diff<?>> diffList,
             final ToStringStyle style) {
-        Validate.notNull(lhs, "Left hand object cannot be null");
-        Validate.notNull(rhs, "Right hand object cannot be null");
-        Validate.notNull(diffs, "List of differences cannot be null");
+        Validate.notNull(lhs, "lhs");
+        Validate.notNull(rhs, "rhs");
+        Validate.notNull(diffList, "diffList");
 
-        this.diffs = diffs;
+        this.diffList = diffList;
         this.lhs = lhs;
         this.rhs = rhs;
 
@@ -117,7 +117,7 @@ public class DiffResult<T> implements Iterable<Diff<?>> {
      * @return an unmodifiable list of {@code Diff}s
      */
     public List<Diff<?>> getDiffs() {
-        return Collections.unmodifiableList(diffs);
+        return Collections.unmodifiableList(diffList);
     }
 
     /**
@@ -128,7 +128,7 @@ public class DiffResult<T> implements Iterable<Diff<?>> {
      * @return the number of differences
      */
     public int getNumberOfDiffs() {
-        return diffs.size();
+        return diffList.size();
     }
 
     /**
@@ -190,14 +190,14 @@ public class DiffResult<T> implements Iterable<Diff<?>> {
      * @return a {@code String} description of the differences.
      */
     public String toString(final ToStringStyle style) {
-        if (diffs.isEmpty()) {
+        if (diffList.isEmpty()) {
             return OBJECTS_SAME_STRING;
         }
 
         final ToStringBuilder lhsBuilder = new ToStringBuilder(lhs, style);
         final ToStringBuilder rhsBuilder = new ToStringBuilder(rhs, style);
 
-        for (final Diff<?> diff : diffs) {
+        for (final Diff<?> diff : diffList) {
             lhsBuilder.append(diff.getFieldName(), diff.getLeft());
             rhsBuilder.append(diff.getFieldName(), diff.getRight());
         }
@@ -215,6 +215,6 @@ public class DiffResult<T> implements Iterable<Diff<?>> {
      */
     @Override
     public Iterator<Diff<?>> iterator() {
-        return diffs.iterator();
+        return diffList.iterator();
     }
 }
diff --git a/src/main/java/org/apache/commons/lang3/builder/HashCodeBuilder.java b/src/main/java/org/apache/commons/lang3/builder/HashCodeBuilder.java
index 7b7bbb0..0a95a74 100644
--- a/src/main/java/org/apache/commons/lang3/builder/HashCodeBuilder.java
+++ b/src/main/java/org/apache/commons/lang3/builder/HashCodeBuilder.java
@@ -358,7 +358,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      */
     public static <T> int reflectionHashCode(final int initialNonZeroOddNumber, final int multiplierNonZeroOddNumber, final T object,
             final boolean testTransients, final Class<? super T> reflectUpToClass, final String... excludeFields) {
-        Validate.notNull(object, "The object to build a hash code for must not be null");
+        Validate.notNull(object, "object");
         final HashCodeBuilder builder = new HashCodeBuilder(initialNonZeroOddNumber, multiplierNonZeroOddNumber);
         Class<?> clazz = object.getClass();
         reflectionAppend(object, clazz, builder, testTransients, excludeFields);
diff --git a/src/main/java/org/apache/commons/lang3/builder/ReflectionToStringBuilder.java b/src/main/java/org/apache/commons/lang3/builder/ReflectionToStringBuilder.java
index d19aa13..66eb15c 100644
--- a/src/main/java/org/apache/commons/lang3/builder/ReflectionToStringBuilder.java
+++ b/src/main/java/org/apache/commons/lang3/builder/ReflectionToStringBuilder.java
@@ -434,7 +434,7 @@ public class ReflectionToStringBuilder extends ToStringBuilder {
     }
 
     private static Object checkNotNull(final Object obj) {
-        return Validate.notNull(obj, "The Object passed in should not be null.");
+        return Validate.notNull(obj, "obj");
     }
 
     /**
diff --git a/src/main/java/org/apache/commons/lang3/builder/ToStringBuilder.java b/src/main/java/org/apache/commons/lang3/builder/ToStringBuilder.java
index 3522ec3..631c6e4 100644
--- a/src/main/java/org/apache/commons/lang3/builder/ToStringBuilder.java
+++ b/src/main/java/org/apache/commons/lang3/builder/ToStringBuilder.java
@@ -133,7 +133,7 @@ public class ToStringBuilder implements Builder<String> {
      * @throws IllegalArgumentException if the style is {@code null}
      */
     public static void setDefaultStyle(final ToStringStyle style) {
-        defaultStyle = Validate.notNull(style, "The style must not be null");
+        defaultStyle = Validate.notNull(style, "style");
     }
 
     //----------------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/lang3/concurrent/BasicThreadFactory.java b/src/main/java/org/apache/commons/lang3/concurrent/BasicThreadFactory.java
index cd50ad1..631f2e4 100644
--- a/src/main/java/org/apache/commons/lang3/concurrent/BasicThreadFactory.java
+++ b/src/main/java/org/apache/commons/lang3/concurrent/BasicThreadFactory.java
@@ -280,7 +280,7 @@ public class BasicThreadFactory implements ThreadFactory {
          * is <b>null</b>
          */
         public Builder wrappedFactory(final ThreadFactory factory) {
-            Validate.notNull(factory, "Wrapped ThreadFactory must not be null!");
+            Validate.notNull(factory, "factory");
 
             wrappedFactory = factory;
             return this;
@@ -295,7 +295,7 @@ public class BasicThreadFactory implements ThreadFactory {
          * @throws NullPointerException if the naming pattern is <b>null</b>
          */
         public Builder namingPattern(final String pattern) {
-            Validate.notNull(pattern, "Naming pattern must not be null!");
+            Validate.notNull(pattern, "pattern");
 
             namingPattern = pattern;
             return this;
@@ -337,7 +337,7 @@ public class BasicThreadFactory implements ThreadFactory {
          */
         public Builder uncaughtExceptionHandler(
                 final Thread.UncaughtExceptionHandler handler) {
-            Validate.notNull(handler, "Uncaught exception handler must not be null!");
+            Validate.notNull(handler, "handler");
 
             exceptionHandler = handler;
             return this;
diff --git a/src/main/java/org/apache/commons/lang3/concurrent/CallableBackgroundInitializer.java b/src/main/java/org/apache/commons/lang3/concurrent/CallableBackgroundInitializer.java
index 6fca65c..26d7d58 100644
--- a/src/main/java/org/apache/commons/lang3/concurrent/CallableBackgroundInitializer.java
+++ b/src/main/java/org/apache/commons/lang3/concurrent/CallableBackgroundInitializer.java
@@ -116,10 +116,10 @@ public class CallableBackgroundInitializer<T> extends BackgroundInitializer<T> {
      * Tests the passed in {@code Callable} and throws an exception if it is
      * undefined.
      *
-     * @param call the object to check
+     * @param callable the object to check
      * @throws IllegalArgumentException if the {@code Callable} is <b>null</b>
      */
-    private void checkCallable(final Callable<T> call) {
-        Validate.notNull(call, "Callable must not be null!");
+    private void checkCallable(final Callable<T> callable) {
+        Validate.notNull(callable, "callable");
     }
 }
diff --git a/src/main/java/org/apache/commons/lang3/concurrent/MultiBackgroundInitializer.java b/src/main/java/org/apache/commons/lang3/concurrent/MultiBackgroundInitializer.java
index 7e36fd9..29b36de 100644
--- a/src/main/java/org/apache/commons/lang3/concurrent/MultiBackgroundInitializer.java
+++ b/src/main/java/org/apache/commons/lang3/concurrent/MultiBackgroundInitializer.java
@@ -127,21 +127,20 @@ public class MultiBackgroundInitializer
      * been invoked.
      *
      * @param name the name of the initializer (must not be <b>null</b>)
-     * @param init the {@code BackgroundInitializer} to add (must not be
+     * @param backgroundInitializer the {@code BackgroundInitializer} to add (must not be
      * <b>null</b>)
      * @throws IllegalArgumentException if a required parameter is missing
      * @throws IllegalStateException if {@code start()} has already been called
      */
-    public void addInitializer(final String name, final BackgroundInitializer<?> init) {
-        Validate.notNull(name, "Name of child initializer must not be null!");
-        Validate.notNull(init, "Child initializer must not be null!");
+    public void addInitializer(final String name, final BackgroundInitializer<?> backgroundInitializer) {
+        Validate.notNull(name, "name");
+        Validate.notNull(backgroundInitializer, "backgroundInitializer");
 
         synchronized (this) {
             if (isStarted()) {
-                throw new IllegalStateException(
-                        "addInitializer() must not be called after start()!");
+                throw new IllegalStateException("addInitializer() must not be called after start()!");
             }
-            childInitializers.put(name, init);
+            childInitializers.put(name, backgroundInitializer);
         }
     }
 
diff --git a/src/main/java/org/apache/commons/lang3/event/EventListenerSupport.java b/src/main/java/org/apache/commons/lang3/event/EventListenerSupport.java
index bd79519..315a612 100644
--- a/src/main/java/org/apache/commons/lang3/event/EventListenerSupport.java
+++ b/src/main/java/org/apache/commons/lang3/event/EventListenerSupport.java
@@ -140,8 +140,8 @@ public class EventListenerSupport<L> implements Serializable {
      */
     public EventListenerSupport(final Class<L> listenerInterface, final ClassLoader classLoader) {
         this();
-        Validate.notNull(listenerInterface, "Listener interface cannot be null.");
-        Validate.notNull(classLoader, "ClassLoader cannot be null.");
+        Validate.notNull(listenerInterface, "listenerInterface");
+        Validate.notNull(classLoader, "classLoader");
         Validate.isTrue(listenerInterface.isInterface(), "Class %s is not an interface",
                 listenerInterface.getName());
         initializeTransientFields(listenerInterface, classLoader);
@@ -194,7 +194,7 @@ public class EventListenerSupport<L> implements Serializable {
      * @since 3.5
      */
     public void addListener(final L listener, final boolean allowDuplicate) {
-        Validate.notNull(listener, "Listener object cannot be null.");
+        Validate.notNull(listener, "listener");
         if (allowDuplicate || !listeners.contains(listener)) {
             listeners.add(listener);
         }
@@ -218,7 +218,7 @@ public class EventListenerSupport<L> implements Serializable {
      *         {@code null}.
      */
     public void removeListener(final L listener) {
-        Validate.notNull(listener, "Listener object cannot be null.");
+        Validate.notNull(listener, "listener");
         listeners.remove(listener);
     }
 
diff --git a/src/main/java/org/apache/commons/lang3/math/Fraction.java b/src/main/java/org/apache/commons/lang3/math/Fraction.java
index e90e340..cb5e1f9 100644
--- a/src/main/java/org/apache/commons/lang3/math/Fraction.java
+++ b/src/main/java/org/apache/commons/lang3/math/Fraction.java
@@ -312,7 +312,7 @@ public final class Fraction extends Number implements Comparable<Fraction> {
      * @throws NumberFormatException if the number format is invalid
      */
     public static Fraction getFraction(String str) {
-        Validate.notNull(str, "The string must not be null");
+        Validate.notNull(str, "str");
         // parse double format
         int pos = str.indexOf('.');
         if (pos >= 0) {
@@ -730,7 +730,7 @@ public final class Fraction extends Number implements Comparable<Fraction> {
      *   cannot be represented in an {@code int}.
      */
     private Fraction addSub(final Fraction fraction, final boolean isAdd) {
-        Validate.notNull(fraction, "The fraction must not be null");
+        Validate.notNull(fraction, "fraction");
         // zero is identity for addition.
         if (numerator == 0) {
             return isAdd ? fraction : fraction.negate();
@@ -778,7 +778,7 @@ public final class Fraction extends Number implements Comparable<Fraction> {
      *  {@code Integer.MAX_VALUE}
      */
     public Fraction multiplyBy(final Fraction fraction) {
-        Validate.notNull(fraction, "The fraction must not be null");
+        Validate.notNull(fraction, "fraction");
         if (numerator == 0 || fraction.numerator == 0) {
             return ZERO;
         }
@@ -801,7 +801,7 @@ public final class Fraction extends Number implements Comparable<Fraction> {
      *  {@code Integer.MAX_VALUE}
      */
     public Fraction divideBy(final Fraction fraction) {
-        Validate.notNull(fraction, "The fraction must not be null");
+        Validate.notNull(fraction, "fraction");
         if (fraction.numerator == 0) {
             throw new ArithmeticException("The fraction to divide by must not be zero");
         }
diff --git a/src/main/java/org/apache/commons/lang3/math/IEEE754rUtils.java b/src/main/java/org/apache/commons/lang3/math/IEEE754rUtils.java
index 1af353d..42d3356 100644
--- a/src/main/java/org/apache/commons/lang3/math/IEEE754rUtils.java
+++ b/src/main/java/org/apache/commons/lang3/math/IEEE754rUtils.java
@@ -37,7 +37,7 @@ public class IEEE754rUtils {
       * @since 3.4 Changed signature from min(double[]) to min(double...)
      */
     public static double min(final double... array) {
-        Validate.notNull(array, "The Array must not be null");
+        Validate.notNull(array, "array");
         Validate.isTrue(array.length != 0, "Array cannot be empty.");
 
         // Finds and returns min
@@ -59,7 +59,7 @@ public class IEEE754rUtils {
      * @since 3.4 Changed signature from min(float[]) to min(float...)
      */
     public static float min(final float... array) {
-        Validate.notNull(array, "The Array must not be null");
+        Validate.notNull(array, "array");
         Validate.isTrue(array.length != 0, "Array cannot be empty.");
 
         // Finds and returns min
@@ -149,7 +149,7 @@ public class IEEE754rUtils {
      * @since 3.4 Changed signature from max(double[]) to max(double...)
      */
     public static double max(final double... array) {
-        Validate.notNull(array, "The Array must not be null");
+        Validate.notNull(array, "array");
         Validate.isTrue(array.length != 0, "Array cannot be empty.");
 
         // Finds and returns max
@@ -171,7 +171,7 @@ public class IEEE754rUtils {
      * @since 3.4 Changed signature from max(float[]) to max(float...)
      */
     public static float max(final float... array) {
-        Validate.notNull(array, "The Array must not be null");
+        Validate.notNull(array, "array");
         Validate.isTrue(array.length != 0, "Array cannot be empty.");
 
         // Finds and returns max
diff --git a/src/main/java/org/apache/commons/lang3/math/NumberUtils.java b/src/main/java/org/apache/commons/lang3/math/NumberUtils.java
index 05e77d1..1433e4a 100644
--- a/src/main/java/org/apache/commons/lang3/math/NumberUtils.java
+++ b/src/main/java/org/apache/commons/lang3/math/NumberUtils.java
@@ -1306,7 +1306,7 @@ public class NumberUtils {
      * @throws IllegalArgumentException if {@code array} is either {@code null} or empty
      */
     private static void validateArray(final Object array) {
-        Validate.notNull(array, "The Array must not be null");
+        Validate.notNull(array, "array");
         Validate.isTrue(Array.getLength(array) != 0, "Array cannot be empty.");
     }
 
diff --git a/src/main/java/org/apache/commons/lang3/reflect/ConstructorUtils.java b/src/main/java/org/apache/commons/lang3/reflect/ConstructorUtils.java
index 72e6be6..bb0b226 100644
--- a/src/main/java/org/apache/commons/lang3/reflect/ConstructorUtils.java
+++ b/src/main/java/org/apache/commons/lang3/reflect/ConstructorUtils.java
@@ -199,7 +199,7 @@ public class ConstructorUtils {
      */
     public static <T> Constructor<T> getAccessibleConstructor(final Class<T> cls,
             final Class<?>... parameterTypes) {
-        Validate.notNull(cls, "class cannot be null");
+        Validate.notNull(cls, "cls");
         try {
             return getAccessibleConstructor(cls.getConstructor(parameterTypes));
         } catch (final NoSuchMethodException e) {
@@ -219,7 +219,7 @@ public class ConstructorUtils {
      * @throws NullPointerException if {@code ctor} is {@code null}
      */
     public static <T> Constructor<T> getAccessibleConstructor(final Constructor<T> ctor) {
-        Validate.notNull(ctor, "constructor cannot be null");
+        Validate.notNull(ctor, "ctor");
         return MemberUtils.isAccessible(ctor)
                 && isAccessible(ctor.getDeclaringClass()) ? ctor : null;
     }
@@ -244,7 +244,7 @@ public class ConstructorUtils {
      */
     public static <T> Constructor<T> getMatchingAccessibleConstructor(final Class<T> cls,
             final Class<?>... parameterTypes) {
-        Validate.notNull(cls, "class cannot be null");
+        Validate.notNull(cls, "cls");
         // see if we can find the constructor directly
         // most of the time this works and it's much faster
         try {
diff --git a/src/main/java/org/apache/commons/lang3/reflect/FieldUtils.java b/src/main/java/org/apache/commons/lang3/reflect/FieldUtils.java
index 0e1ed7a..bbf24d1 100644
--- a/src/main/java/org/apache/commons/lang3/reflect/FieldUtils.java
+++ b/src/main/java/org/apache/commons/lang3/reflect/FieldUtils.java
@@ -86,7 +86,7 @@ public class FieldUtils {
      * in the inheritance hierarchy
      */
     public static Field getField(final Class<?> cls, final String fieldName, final boolean forceAccess) {
-        Validate.notNull(cls, "The class must not be null");
+        Validate.notNull(cls, "cls");
         Validate.isTrue(StringUtils.isNotBlank(fieldName), "The field name must not be blank/empty");
         // FIXME is this workaround still needed? lang requires Java 6
         // Sun Java 1.3 has a bugged implementation of getField hence we write the
@@ -169,7 +169,7 @@ public class FieldUtils {
      *             if the class is {@code null}, or the field name is blank or empty
      */
     public static Field getDeclaredField(final Class<?> cls, final String fieldName, final boolean forceAccess) {
-        Validate.notNull(cls, "The class must not be null");
+        Validate.notNull(cls, "cls");
         Validate.isTrue(StringUtils.isNotBlank(fieldName), "The field name must not be blank/empty");
         try {
             // only consider the specified class by using getDeclaredField()
@@ -214,7 +214,7 @@ public class FieldUtils {
      * @since 3.2
      */
     public static List<Field> getAllFieldsList(final Class<?> cls) {
-        Validate.notNull(cls, "The class must not be null");
+        Validate.notNull(cls, "cls");
         final List<Field> allFields = new ArrayList<>();
         Class<?> currentClass = cls;
         while (currentClass != null) {
@@ -253,7 +253,7 @@ public class FieldUtils {
      * @since 3.4
      */
     public static List<Field> getFieldsListWithAnnotation(final Class<?> cls, final Class<? extends Annotation> annotationCls) {
-        Validate.notNull(annotationCls, "The annotation class must not be null");
+        Validate.notNull(annotationCls, "annotationCls");
         final List<Field> allFields = getAllFieldsList(cls);
         final List<Field> annotatedFields = new ArrayList<>();
         for (final Field field : allFields) {
@@ -294,7 +294,7 @@ public class FieldUtils {
      *             if the field is not made accessible
      */
     public static Object readStaticField(final Field field, final boolean forceAccess) throws IllegalAccessException {
-        Validate.notNull(field, "The field must not be null");
+        Validate.notNull(field, "field");
         Validate.isTrue(Modifier.isStatic(field.getModifiers()), "The field '%s' is not static", field.getName());
         return readField(field, (Object) null, forceAccess);
     }
@@ -420,7 +420,7 @@ public class FieldUtils {
      *             if the field is not made accessible
      */
     public static Object readField(final Field field, final Object target, final boolean forceAccess) throws IllegalAccessException {
-        Validate.notNull(field, "The field must not be null");
+        Validate.notNull(field, "field");
         if (forceAccess && !field.isAccessible()) {
             field.setAccessible(true);
         } else {
@@ -464,7 +464,7 @@ public class FieldUtils {
      *             if the named field is not made accessible
      */
     public static Object readField(final Object target, final String fieldName, final boolean forceAccess) throws IllegalAccessException {
-        Validate.notNull(target, "target object must not be null");
+        Validate.notNull(target, "target");
         final Class<?> cls = target.getClass();
         final Field field = getField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate field %s on %s", fieldName, cls);
@@ -507,7 +507,7 @@ public class FieldUtils {
      *             if the field is not made accessible
      */
     public static Object readDeclaredField(final Object target, final String fieldName, final boolean forceAccess) throws IllegalAccessException {
-        Validate.notNull(target, "target object must not be null");
+        Validate.notNull(target, "target");
         final Class<?> cls = target.getClass();
         final Field field = getDeclaredField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate declared field %s.%s", cls, fieldName);
@@ -548,7 +548,7 @@ public class FieldUtils {
      *             if the field is not made accessible or is {@code final}
      */
     public static void writeStaticField(final Field field, final Object value, final boolean forceAccess) throws IllegalAccessException {
-        Validate.notNull(field, "The field must not be null");
+        Validate.notNull(field, "field");
         Validate.isTrue(Modifier.isStatic(field.getModifiers()), "The field %s.%s is not static", field.getDeclaringClass().getName(),
                 field.getName());
         writeField(field, (Object) null, value, forceAccess);
@@ -682,7 +682,7 @@ public class FieldUtils {
      */
     public static void writeField(final Field field, final Object target, final Object value, final boolean forceAccess)
             throws IllegalAccessException {
-        Validate.notNull(field, "The field must not be null");
+        Validate.notNull(field, "field");
         if (forceAccess && !field.isAccessible()) {
             field.setAccessible(true);
         } else {
@@ -722,7 +722,7 @@ public class FieldUtils {
      */
     @Deprecated
     public static void removeFinalModifier(final Field field, final boolean forceAccess) {
-        Validate.notNull(field, "The field must not be null");
+        Validate.notNull(field, "field");
 
         try {
             if (Modifier.isFinal(field.getModifiers())) {
@@ -791,7 +791,7 @@ public class FieldUtils {
      */
     public static void writeField(final Object target, final String fieldName, final Object value, final boolean forceAccess)
             throws IllegalAccessException {
-        Validate.notNull(target, "target object must not be null");
+        Validate.notNull(target, "target");
         final Class<?> cls = target.getClass();
         final Field field = getField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate declared field %s.%s", cls.getName(), fieldName);
@@ -839,7 +839,7 @@ public class FieldUtils {
      */
     public static void writeDeclaredField(final Object target, final String fieldName, final Object value, final boolean forceAccess)
             throws IllegalAccessException {
-        Validate.notNull(target, "target object must not be null");
+        Validate.notNull(target, "target");
         final Class<?> cls = target.getClass();
         final Field field = getDeclaredField(cls, fieldName, forceAccess);
         Validate.isTrue(field != null, "Cannot locate declared field %s.%s", cls.getName(), fieldName);
diff --git a/src/main/java/org/apache/commons/lang3/reflect/MethodUtils.java b/src/main/java/org/apache/commons/lang3/reflect/MethodUtils.java
index 3ddeac5..615a569 100644
--- a/src/main/java/org/apache/commons/lang3/reflect/MethodUtils.java
+++ b/src/main/java/org/apache/commons/lang3/reflect/MethodUtils.java
@@ -740,8 +740,8 @@ public class MethodUtils {
      */
     public static Method getMatchingMethod(final Class<?> cls, final String methodName,
             final Class<?>... parameterTypes) {
-        Validate.notNull(cls, "Null class not allowed.");
-        Validate.notEmpty(methodName, "Null or blank methodName not allowed.");
+        Validate.notNull(cls, "cls");
+        Validate.notEmpty(methodName, "methodName");
 
         // Address methods in superclasses
         Method[] methodArray = cls.getDeclaredMethods();
@@ -908,8 +908,8 @@ public class MethodUtils {
                                                             final Class<? extends Annotation> annotationCls,
                                                             final boolean searchSupers, final boolean ignoreAccess) {
 
-        Validate.notNull(cls, "The class must not be null");
-        Validate.notNull(annotationCls, "The annotation class must not be null");
+        Validate.notNull(cls, "cls");
+        Validate.notNull(annotationCls, "annotationCls");
         final List<Class<?>> classes = (searchSupers ? getAllSuperclassesAndInterfaces(cls)
                 : new ArrayList<>());
         classes.add(0, cls);
@@ -950,8 +950,8 @@ public class MethodUtils {
     public static <A extends Annotation> A getAnnotation(final Method method, final Class<A> annotationCls,
                                                          final boolean searchSupers, final boolean ignoreAccess) {
 
-        Validate.notNull(method, "The method must not be null");
-        Validate.notNull(annotationCls, "The annotation class must not be null");
+        Validate.notNull(method, "method");
+        Validate.notNull(annotationCls, "annotationCls");
         if (!ignoreAccess && !MemberUtils.isAccessible(method)) {
             return null;
         }
diff --git a/src/main/java/org/apache/commons/lang3/time/DateUtils.java b/src/main/java/org/apache/commons/lang3/time/DateUtils.java
index 917515d..3904062 100644
--- a/src/main/java/org/apache/commons/lang3/time/DateUtils.java
+++ b/src/main/java/org/apache/commons/lang3/time/DateUtils.java
@@ -1786,7 +1786,7 @@ public class DateUtils {
     }
 
     private static void validateDateNotNull(final Date date) {
-        Validate.notNull(date, "The date must not be null");
+        Validate.notNull(date, "date");
     }
 
     //-----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/lang3/time/FormatCache.java b/src/main/java/org/apache/commons/lang3/time/FormatCache.java
index a268203..14bc299 100644
--- a/src/main/java/org/apache/commons/lang3/time/FormatCache.java
+++ b/src/main/java/org/apache/commons/lang3/time/FormatCache.java
@@ -69,7 +69,7 @@ abstract class FormatCache<F extends Format> {
      * @throws IllegalArgumentException if pattern is invalid
      */
     public F getInstance(final String pattern, TimeZone timeZone, Locale locale) {
-        Validate.notNull(pattern, "pattern must not be null");
+        Validate.notNull(pattern, "pattern");
         if (timeZone == null) {
             timeZone = TimeZone.getDefault();
         }
diff --git a/src/test/java/org/apache/commons/lang3/CharRangeTest.java b/src/test/java/org/apache/commons/lang3/CharRangeTest.java
index 8d59a55..b3104fb 100644
--- a/src/test/java/org/apache/commons/lang3/CharRangeTest.java
+++ b/src/test/java/org/apache/commons/lang3/CharRangeTest.java
@@ -312,7 +312,7 @@ public class CharRangeTest  {
     public void testContainsNullArg() {
         final CharRange range = CharRange.is('a');
         final NullPointerException e = assertThrows(NullPointerException.class, () -> range.contains(null));
-        assertEquals("The Range must not be null", e.getMessage());
+        assertEquals("range", e.getMessage());
     }
 
     @Test
diff --git a/src/main/java/org/apache/commons/lang3/reflect/TypeUtils.java b/src/main/java/org/apache/commons/lang3/reflect/TypeUtils.java
index 5fe03af..7d90421 100644
--- a/src/main/java/org/apache/commons/lang3/reflect/TypeUtils.java
+++ b/src/main/java/org/apache/commons/lang3/reflect/TypeUtils.java
@@ -405,18 +405,18 @@ public class TypeUtils {
      * </p>
      *
      * @param cls the class whose type parameters are to be determined, not {@code null}
      * @param superType the super type from which {@code cls}'s type
      * arguments are to be determined, not {@code null}
      * @return a {@code Map} of the type assignments that could be determined
      * for the type variables in each type in the inheritance hierarchy from
      * {@code type} to {@code toClass} inclusive.
      */
     public static Map<TypeVariable<?>, Type> determineTypeArguments(final Class<?> cls,
-            final ParameterizedType superType) {
-        Validate.notNull(cls, "cls is null");
-        Validate.notNull(superType, "superType is null");
+            final ParameterizedType superParameterizedType) {
+        Validate.notNull(cls, "cls");
+        Validate.notNull(superParameterizedType, "superParameterizedType");
 
-        final Class<?> superClass = getRawType(superType);
+        final Class<?> superClass = getRawType(superParameterizedType);
 
         // compatibility check
         if (!isAssignable(cls, superClass)) {
@@ -424,7 +424,7 @@ public class TypeUtils {
         }
 
         if (cls.equals(superClass)) {
-            return getTypeArguments(superType, superClass, null);
+            return getTypeArguments(superParameterizedType, superClass, null);
         }
 
         // get the next class in the inheritance hierarchy
@@ -432,14 +432,14 @@ public class TypeUtils {
 
         // can only be a class or a parameterized type
         if (midType instanceof Class<?>) {
-            return determineTypeArguments((Class<?>) midType, superType);
+            return determineTypeArguments((Class<?>) midType, superParameterizedType);
         }
 
         final ParameterizedType midParameterizedType = (ParameterizedType) midType;
         final Class<?> midClass = getRawType(midParameterizedType);
         // get the type variables of the mid class that map to the type
         // arguments of the super class
-        final Map<TypeVariable<?>, Type> typeVarAssigns = determineTypeArguments(midClass, superType);
+        final Map<TypeVariable<?>, Type> typeVarAssigns = determineTypeArguments(midClass, superParameterizedType);
         // map the arguments of the mid type to the class type variables
         mapTypeVariablesToArguments(cls, midParameterizedType, typeVarAssigns);
 
@@ -580,7 +580,7 @@ public class TypeUtils {
      * @since 3.2
      */
     public static GenericArrayType genericArrayType(final Type componentType) {
-        return new GenericArrayTypeImpl(Validate.notNull(componentType, "componentType is null"));
+        return new GenericArrayTypeImpl(Validate.notNull(componentType, "componentType"));
     }
 
     /**
@@ -669,7 +669,7 @@ public class TypeUtils {
      * @return a non-empty array containing the bounds of the type variable.
      */
     public static Type[] getImplicitBounds(final TypeVariable<?> typeVariable) {
-        Validate.notNull(typeVariable, "typeVariable is null");
+        Validate.notNull(typeVariable, "typeVariable");
         final Type[] bounds = typeVariable.getBounds();
 
         return bounds.length == 0 ? new Type[] { Object.class } : normalizeUpperBounds(bounds);
@@ -685,7 +685,7 @@ public class TypeUtils {
      * type.
      */
     public static Type[] getImplicitLowerBounds(final WildcardType wildcardType) {
-        Validate.notNull(wildcardType, "wildcardType is null");
+        Validate.notNull(wildcardType, "wildcardType");
         final Type[] bounds = wildcardType.getLowerBounds();
 
         return bounds.length == 0 ? new Type[] { null } : bounds;
@@ -702,7 +702,7 @@ public class TypeUtils {
      * type.
      */
     public static Type[] getImplicitUpperBounds(final WildcardType wildcardType) {
-        Validate.notNull(wildcardType, "wildcardType is null");
+        Validate.notNull(wildcardType, "wildcardType");
         final Type[] bounds = wildcardType.getUpperBounds();
 
         return bounds.length == 0 ? new Type[] { Object.class } : normalizeUpperBounds(bounds);
@@ -1503,7 +1503,7 @@ public class TypeUtils {
      * redundant types.
      */
     public static Type[] normalizeUpperBounds(final Type[] bounds) {
-        Validate.notNull(bounds, "null value specified for bounds array");
+        Validate.notNull(bounds, "bounds");
         // don't bother if there's only one (or none) type
         if (bounds.length < 2) {
             return bounds;
@@ -1533,16 +1533,16 @@ public class TypeUtils {
      * Creates a parameterized type instance.
      *
      * @param rawClass the raw class to create a parameterized type instance for
-     * @param typeArgMappings the mapping used for parameterization
+     * @param typeVariableMap the map used for parameterization
      * @return {@link ParameterizedType}
      * @since 3.2
      */
     public static final ParameterizedType parameterize(final Class<?> rawClass,
-        final Map<TypeVariable<?>, Type> typeArgMappings) {
-        Validate.notNull(rawClass, "raw class is null");
-        Validate.notNull(typeArgMappings, "typeArgMappings is null");
+        final Map<TypeVariable<?>, Type> typeVariableMap) {
+        Validate.notNull(rawClass, "rawClass");
+        Validate.notNull(typeVariableMap, "typeVariableMap");
         return parameterizeWithOwner(null, rawClass,
-            extractTypeArgumentsFrom(typeArgMappings, rawClass.getTypeParameters()));
+            extractTypeArgumentsFrom(typeVariableMap, rawClass.getTypeParameters()));
     }
 
     /**
@@ -1597,16 +1597,16 @@ public class TypeUtils {
      *
      * @param owner the owning type
      * @param rawClass the raw class to create a parameterized type instance for
-     * @param typeArgMappings the mapping used for parameterization
+     * @param typeVariableMap the map used for parameterization
      * @return {@link ParameterizedType}
      * @since 3.2
      */
     public static final ParameterizedType parameterizeWithOwner(final Type owner, final Class<?> rawClass,
-        final Map<TypeVariable<?>, Type> typeArgMappings) {
-        Validate.notNull(rawClass, "raw class is null");
-        Validate.notNull(typeArgMappings, "typeArgMappings is null");
+        final Map<TypeVariable<?>, Type> typeVariableMap) {
+        Validate.notNull(rawClass, "rawClass");
+        Validate.notNull(typeVariableMap, "typeVariableMap");
         return parameterizeWithOwner(owner, rawClass,
-            extractTypeArgumentsFrom(typeArgMappings, rawClass.getTypeParameters()));
+            extractTypeArgumentsFrom(typeVariableMap, rawClass.getTypeParameters()));
     }
 
     /**
@@ -1621,7 +1621,7 @@ public class TypeUtils {
      */
     public static final ParameterizedType parameterizeWithOwner(final Type owner, final Class<?> rawClass,
         final Type... typeArguments) {
-        Validate.notNull(rawClass, "raw class is null");
+        Validate.notNull(rawClass, "rawClass");
         final Type useOwner;
         if (rawClass.getEnclosingClass() == null) {
             Validate.isTrue(owner == null, "no owner allowed for top-level %s", rawClass);
@@ -1665,14 +1665,14 @@ public class TypeUtils {
     /**
      * Formats a {@link TypeVariable} including its {@link GenericDeclaration}.
      *
-     * @param var the type variable to create a String representation for, not {@code null}
+     * @param typeVariable the type variable to create a String representation for, not {@code null}
      * @return String
      * @since 3.2
      */
-    public static String toLongString(final TypeVariable<?> var) {
-        Validate.notNull(var, "var is null");
+    public static String toLongString(final TypeVariable<?> typeVariable) {
+        Validate.notNull(typeVariable, "typeVariable");
         final StringBuilder buf = new StringBuilder();
-        final GenericDeclaration d = var.getGenericDeclaration();
+        final GenericDeclaration d = typeVariable.getGenericDeclaration();
         if (d instanceof Class<?>) {
             Class<?> c = (Class<?>) d;
             while (true) {
@@ -1688,7 +1688,7 @@ public class TypeUtils {
         } else {
             buf.append(d);
         }
-        return buf.append(':').append(typeVariableToString(var)).toString();
+        return buf.append(':').append(typeVariableToString(typeVariable)).toString();
     }
 
     private static <T> String toString(final T object) {
@@ -1730,22 +1730,22 @@ public class TypeUtils {
      * another type variable to be specified, the dependencies must be included
      * in {@code typeVarAssigns}.
      *
      * @param typeVarAssigns specifies the potential types to be assigned to the
      * type variables, not {@code null}.
      * @return whether or not the types can be assigned to their respective type
      * variables.
      */
-    public static boolean typesSatisfyVariables(final Map<TypeVariable<?>, Type> typeVarAssigns) {
-        Validate.notNull(typeVarAssigns, "typeVarAssigns is null");
+    public static boolean typesSatisfyVariables(final Map<TypeVariable<?>, Type> typeVariableMap) {
+        Validate.notNull(typeVariableMap, "typeVariableMap");
         // all types must be assignable to all the bounds of their mapped
         // type variable.
-        for (final Map.Entry<TypeVariable<?>, Type> entry : typeVarAssigns.entrySet()) {
+        for (final Map.Entry<TypeVariable<?>, Type> entry : typeVariableMap.entrySet()) {
             final TypeVariable<?> typeVar = entry.getKey();
             final Type type = entry.getValue();
 
             for (final Type bound : getImplicitBounds(typeVar)) {
-                if (!isAssignable(type, substituteTypeVariables(bound, typeVarAssigns),
-                        typeVarAssigns)) {
+                if (!isAssignable(type, substituteTypeVariables(bound, typeVariableMap),
+                        typeVariableMap)) {
                     return false;
                 }
             }
@@ -405,18 +405,18 @@ public class TypeUtils {
      *
      * @param cls the class whose type parameters are to be determined, not {@code null}
-     * @param superType the super type from which {@code cls}'s type
+     * @param superParameterizedType the super type from which {@code cls}'s type
      * arguments are to be determined, not {@code null}
      * @return a {@code Map} of the type assignments that could be determined
@@ -1730,22 +1730,22 @@ public class TypeUtils {
      * in {@code typeVarAssigns}.
      *
-     * @param typeVarAssigns specifies the potential types to be assigned to the
+     * @param typeVariableMap specifies the potential types to be assigned to the
      * type variables, not {@code null}.
      * @return whether or not the types can be assigned to their respective type